"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const all_1 = require("aws-sdk/clients/all");
const ResponseBase_1 = require("../../Models/ResponseBase");
class DynamoDbService {
    constructor(options) {
        this.options = options;
    }
    save(item) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                var response = new ResponseBase_1.default();
                const connector = this.GetDynamoDbConnector();
                const dbItem = Object.assign({}, this.GetDbItem(), { Item: item });
                connector.put(dbItem)
                    .promise()
                    .then((putItemOutput) => {
                    resolve(response);
                })
                    .catch((error) => {
                    response.isSuccess = false;
                    response.error = error;
                    resolve(response);
                });
            });
        });
    }
    get(queryKeys) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                var response = new ResponseBase_1.default();
                const connector = this.GetDynamoDbConnector();
                const dbItem = Object.assign({}, this.GetDbItem(), queryKeys.getQueryKeys());
                connector.get(dbItem)
                    .promise()
                    .then((getItemOutput) => {
                    response.data = getItemOutput.Item;
                    resolve(response);
                })
                    .catch((error) => {
                    console.log(error);
                    response.isSuccess = false;
                    response.error = error;
                    resolve(response);
                });
            });
        });
    }
    query(queryKeys) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                var response = new ResponseBase_1.default();
                const connector = this.GetDynamoDbConnector();
                const dbItem = Object.assign({}, this.GetDbItem(), { ScanIndexForward: this.options.SortAscending }, this.GetQueryExpressionParams(queryKeys));
                connector.query(dbItem)
                    .promise()
                    .then((queryOutput) => {
                    console.log(queryOutput);
                    response.data = queryOutput.Items;
                    resolve(response);
                })
                    .catch((error) => {
                    console.log(error);
                    response.isSuccess = false;
                    response.error = error;
                    resolve(response);
                });
            });
        });
    }
    delete(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                var response = new ResponseBase_1.default();
                const connector = this.GetDynamoDbConnector();
                const dbItem = Object.assign({}, this.GetDbItem(), { Key: { [key]: value } });
                connector.delete(dbItem)
                    .promise()
                    .then((deleteItemOutput) => {
                    resolve(response);
                })
                    .catch((error) => {
                    response.isSuccess = false;
                    response.error = error;
                    resolve(response);
                });
            });
        });
    }
    GetDynamoDbConnector() {
        return process.env.mode === 'dev' ?
            new all_1.DynamoDB.DocumentClient({
                region: this.options.Region,
                accessKeyId: this.options.AccessKey,
                secretAccessKey: this.options.Secret
            }) :
            new all_1.DynamoDB.DocumentClient({
                region: this.options.Region
            });
    }
    GetDbItem() {
        return {
            TableName: this.options.TableName,
            IndexName: this.options.IndexName,
            ReturnConsumedCapacity: "TOTAL"
        };
    }
    GetQueryExpressionParams(queryKeys) {
        const data = queryKeys.getData();
        var expressionParams = {};
        var keyConditionExpression = '';
        for (let index = 0; index < data.length; index++) {
            const element = data[index];
            expressionParams[`:${element.key}`] = element.value;
            keyConditionExpression += `${element.key} = :${element.key}`;
            if (index !== data.length - 1) {
                keyConditionExpression += ' AND ';
            }
        }
        return {
            ExpressionAttributeValues: expressionParams,
            KeyConditionExpression: keyConditionExpression
        };
    }
}
exports.default = DynamoDbService;
//# sourceMappingURL=DybamoDbService.js.map